@@ -141,7 +141,7 @@ def import_publication(
         pdf_path = sync_paths[0].removesuffix(".tex") + ".pdf"
         typer.echo(f"Using PDF path: {pdf_path}")
     tex_path = pdf_path.removesuffix(".pdf") + ".tex"
-    pub_path = os.path.join(dest_dir, pdf_path)
+    pub_path = PurePosixPath(dest_dir, pdf_path).as_posix()
     pub_paths = [pub.get("path") for pub in pubs]
     if not overwrite and pub_path in pub_paths:
         raise_error(
@@ -272,7 +272,20 @@ def sync(
         bool,
         typer.Option(
             "--no-commit",
-            help="Do not commit the changes.",
+            help=(
+                "Do not commit the changes to the project repo. "
+                "Changes will always be committed to Overleaf."
+            ),
+        ),
+    ] = False,
+    no_push: Annotated[
+        bool,
+        typer.Option(
+            "--no-push",
+            help=(
+                "Do not push the changes to the project remote. "
+                "Changes will always be pushed to Overleaf."
+            ),
         ),
     ] = False,
     verbose: Annotated[
@@ -342,16 +355,27 @@ def sync(
         last_sync_commit = pub["overleaf"].get("last_sync_commit")
         # Determine which paths to sync and push
         # TODO: Support glob patterns
-        sync_paths = pub["overleaf"].get("sync_paths", [])
+        git_sync_paths = pub["overleaf"].get("sync_paths", [])
+        git_sync_paths += pub["overleaf"].get("git_sync_paths", [])
+        dvc_sync_paths = pub["overleaf"].get("dvc_sync_paths", [])
+        sync_paths = git_sync_paths + dvc_sync_paths
         push_paths = pub["overleaf"].get("push_paths", [])
-        sync_paths_in_project = [os.path.join(wdir, p) for p in sync_paths]
+        git_sync_paths_in_project = [
+            os.path.join(wdir, p) for p in git_sync_paths
+        ]
+        dvc_sync_paths_in_project = [
+            os.path.join(wdir, p) for p in dvc_sync_paths
+        ]
         if not sync_paths:
-            warn("No sync paths defined in the publication's Overleaf config")
+            warn(
+                "No sync paths or DVC sync paths defined in the publication's "
+                "Overleaf config"
+            )
         elif last_sync_commit:
             # Compute a diff in the Overleaf project between HEAD and the last
             # sync
             diff = overleaf_repo.git.diff(
-                [last_sync_commit, "HEAD", "--"] + sync_paths
+                [last_sync_commit, "HEAD", "--"] + git_sync_paths
             )
             # Ensure the diff ends with a new line
             if diff and not diff.endswith("\n"):
@@ -412,18 +436,14 @@ def sync(
                 continue
         # Stage the changes in the Overleaf project
         overleaf_repo.git.add(sync_paths + push_paths)
-        if (
-            overleaf_repo.git.diff("--staged", sync_paths + push_paths)
-            and not no_commit
-        ):
+        if overleaf_repo.git.diff("--staged", sync_paths + push_paths):
+            typer.echo("Committing changes to Overleaf")
             commit_message = "Sync with Calkit project"
             overleaf_repo.git.commit(
                 *(sync_paths + push_paths),
                 "-m",
                 commit_message,
             )
-            # TODO: We should probably always push and pull to we can
-            # idempotently run this command
             typer.echo("Pushing changes to Overleaf")
             overleaf_repo.git.push()
         # Update the last sync commit
@@ -436,19 +456,41 @@ def sync(
             calkit.ryaml.dump(ck_info, f)
         repo.git.add("calkit.yaml")
         # Stage the changes in the project repo
-        repo.git.add(sync_paths_in_project)
+        # Add any DVC sync paths to DVC
+        for dvc_sync_path in dvc_sync_paths_in_project:
+            if not os.path.isfile(dvc_sync_path):
+                raise_error(
+                    f"DVC sync path {dvc_sync_path} does not exist; "
+                    "please check your Overleaf config"
+                )
+            typer.echo(f"Adding DVC sync path {dvc_sync_path} to DVC")
+            try:
+                subprocess.run(
+                    ["python", "-m", "dvc", "-q", "add", dvc_sync_path],
+                    check=True,
+                )
+            except subprocess.CalledProcessError as e:
+                raise_error(
+                    f"Failed to add DVC sync path {dvc_sync_path}: {e}"
+                )
+        repo.git.add(git_sync_paths_in_project)
         if (
-            repo.git.diff("--staged", sync_paths_in_project + ["calkit.yaml"])
+            repo.git.diff(
+                "--staged", git_sync_paths_in_project + ["calkit.yaml"]
+            )
             and not no_commit
         ):
             typer.echo("Committing changes to project repo")
             commit_message = f"Sync {wdir} with Overleaf project"
             repo.git.commit(
-                *(sync_paths_in_project + ["calkit.yaml"]),
+                *(git_sync_paths_in_project + ["calkit.yaml"]),
                 "-m",
                 commit_message,
             )
-    # Push to the project remote
-    typer.echo("Pushing changes to project Git remote")
-    repo.git.push()
+    if not no_push and not no_commit:
+        # Push to the project remote
+        typer.echo("Pushing changes to project Git remote")
+        repo.git.push()
+        if dvc_sync_paths:
+            subprocess.run(["python", "-m", "dvc", "push"])
     # TODO: Add option to run the pipeline after?
